package
Version:
v0.4.3
Opens a new window with list of versions in this module.
Published: Jun 4, 2026
License: LGPL-2.1
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package ramview provides RAMView — a memory-utilization bar with
used / free / total annotations.
RAMView paints "RAM 4.2 / 16.0 GiB ████████░░".
New constructs a RAMView.
GetTypeID for serial registry.
type Sampler func() Stats
Sampler returns current Stats.
type Stats struct {
Used, Total uint64
}
Stats reports memory usage in bytes.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.