Documentation
¶
Overview ¶
Package barchart provides BarChart — a simple labeled bar chart (horizontal bars only, with auto-scaling and value annotations).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BarChart ¶
type BarChart struct {
views.Base
Bars []Bar
ShowValue bool
BarChar rune
BackChar rune
BarAttr uint16
BackAttr uint16
LabelAttr uint16
ValueAttr uint16
}
BarChart renders a stack of horizontal bars filling a column block. Label is left-aligned, then the bar fills the remaining width proportional to Value / max(Values), then a numeric annotation.
Click to show internal directories.
Click to hide internal directories.